Class: CovLoupe::ModelData

Inherits:
Data
  • Object
show all
Defined in:
lib/cov_loupe/model/model_data.rb

Overview

Immutable data container for coverage data loaded from a specific resultset file. Holds the normalized coverage map, timestamp, and resultset path.

This class has no awareness of caching - it's managed by ModelDataCache.

Instance Attribute Summary collapse

Instance Attribute Details

#coverage_mapHash (readonly)

Map of absolute file paths to coverage data

Returns:

  • (Hash)

    the current value of coverage_map



12
13
14
# File 'lib/cov_loupe/model/model_data.rb', line 12

def coverage_map
  @coverage_map
end

#resultset_pathString (readonly)

Absolute path to the .resultset.json file

Returns:

  • (String)

    the current value of resultset_path



12
13
14
# File 'lib/cov_loupe/model/model_data.rb', line 12

def resultset_path
  @resultset_path
end

#timestampInteger (readonly)

Latest timestamp from coverage suites

Returns:

  • (Integer)

    the current value of timestamp



12
13
14
# File 'lib/cov_loupe/model/model_data.rb', line 12

def timestamp
  @timestamp
end